pub fn load(path: &Path) -> Result<ResumeState>Expand description
Load resume JSON from path, or an empty state when the file is missing.
Errors
Returns HortoError::Io on read failure, or
HortoError::Json when the file is not valid JSON.
pub fn load(path: &Path) -> Result<ResumeState>Load resume JSON from path, or an empty state when the file is missing.
Returns HortoError::Io on read failure, or
HortoError::Json when the file is not valid JSON.